package com.diagbot.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.entity.LantoneProduct;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.service.impl.LantoneProductServiceImpl;
import com.diagbot.util.UserUtils;
import org.springframework.stereotype.Component;

/**
 * @Description:产品业务层
 * @author: wangyu
 * @time: 2018/9/19 15:52
 */
@Component
public class LantoneProductFacade extends LantoneProductServiceImpl {
    /**
     * @Description: 添加产品业务逻辑
     * @Author: wangyu
     * @Date: 19:59 2018/9/18
     */
    public CommonErrorCode addProducts(LantoneProduct lantoneProduct) {
        LantoneProduct diagLantoneProduct1 = new LantoneProduct();

        if (!save(lantoneProduct)) {
            return CommonErrorCode.FAIL;
        }
        return CommonErrorCode.OK;
    }

    /**
     * @Description: 修改产品业务逻辑
     * @Author: wangyu
     * @Date: 19:59 2018/9/18
     */
    public CommonErrorCode updateProduct(LantoneProduct lantoneProduct) {
        if (!updateById(lantoneProduct)) {
            return CommonErrorCode.FAIL;
        }
        return CommonErrorCode.OK;
    }

    /**
     * @Description: 删除产品业务逻辑
     * @Author: wangyu
     * @Date: 19:59 2018/9/18
     */
    public CommonErrorCode deleteProduct(LantoneProduct lantoneProduct) {
        lantoneProduct.setIsDeleted("Y");
        if (!updateById(lantoneProduct)) {
            return CommonErrorCode.FAIL;
        }
        return CommonErrorCode.OK;
    }

    /**
     * @Description: 更改产品状态业务逻辑
     * @Author: wangyu
     * @Date: 19:59 2018/9/18
     */
    public CommonErrorCode productStatus(LantoneProduct lantoneProduct) {
        if (!updateById(lantoneProduct)) {
            return CommonErrorCode.FAIL;
        }
        return CommonErrorCode.OK;
    }

    /**
     * @Description: 根据用户id查询是否有开通产品
     * @Author: wangyu
     * @Date: 19:59 2018/9/18
     */
    public IPage<LantoneProduct> productLine(Page page){
        Long userId = Long.parseLong(UserUtils.getCurrentPrincipleID());
        IPage<LantoneProduct> diagLantoneProducts =productLine(page,userId);
        return diagLantoneProducts;
    }
}
