package com.diagbot.web;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.ResultModelDTO;
import com.diagbot.dto.UserInfoDTO;
import com.diagbot.entity.Organization;
import com.diagbot.entity.User;
import com.diagbot.facade.OrganizationFacade;
import com.diagbot.facade.UserFacade;
import com.diagbot.util.DateUtil;
import com.diagbot.vo.OrganizationVO;
import com.diagbot.vo.UserAndOrganizationVO;
import com.diagbot.vo.UserInfoOrganizationsVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * @Description: 外部用户信息
 * @author: wangfeng
 * @time: 2018年9月17日 下午1:53:53
 */
@RestController
@Api(value="用户信息和机构信息API", tags={"用户信息和机构信息API"})
@RequestMapping("/userInfo")
public class UserInfoController {
	
	@Autowired
    private UserFacade userFacade;
	@Autowired
	OrganizationFacade organizationFacade;
	
	private final String MSG_SUCCESS = "操作成功!";
    private final String MSG_ERROR = "操作失败!";
	
	    @ApiOperation(value = "分页查询获取用户信息", notes = "根据每页显示条数，默认 10，和当前页")
	    @PostMapping("/getUserInfoPag")
	    @SysLogger("getUserInfoPag")
//	    @ApiIgnore
	    public RespDTO<UserInfoDTO> getUserInfoPag(Page page, String orgName, String autStatus ){
	    	UserInfoDTO userInfo =new UserInfoDTO();
	    	userInfo.setOrgName(orgName);
	    	userInfo.setAutStatus(autStatus);
	        IPage<UserInfoDTO> user=  userFacade.selectUserInfoListPage(page,userInfo);
	        return RespDTO.onSuc(user);
	    }
	    
	    @ApiOperation(value = "修改用户信息和机构信息以", notes = "用户信息和机构信息")
	    @PostMapping("/updateUserInfoAll")
	    @SysLogger("updateUserInfoAll")
	    public RespDTO<UserInfoOrganizationsVO> updateUserInfoAll( UserInfoOrganizationsVO userInfo){
	         int res = userFacade.updateUserInfoAll(userInfo);
	         
	        return RespDTO.onSuc("修改成功"+res);
	    }
	    
	    @ApiOperation(value = "删除用户信息和机构信息", notes = "用户信息和机构信息")
	    @PostMapping("/updateDeleted")
	    @SysLogger("updateDeleted")
	    public RespDTO updateDeleted(@RequestParam String  userId){
	    	Map<String,String> map = new HashMap<String, String>();
	    	map.put("userId", userId);
	    	//TODO map.put("modifier",UserUtils.getCurrentPrincipleID());
	    	map.put("modifier","5");
	    	map.put("gmtModified",DateUtil.DATE_TIME_FORMAT);
	    	 int res= userFacade.updateDeleted(map);
	    	 return RespDTO.onSuc("刪除成功"+res);
	    }
	    
	    @ApiOperation(value = "模糊查询机构信息", notes = "机构信息")
	    @PostMapping("/findOrganization")
	    @SysLogger("findOrganization")
	    public RespDTO findOrganization(@RequestParam String  organizationName){
	    	//TODO 返回机构Id和机构
	    	List<Organization> organization = organizationFacade.findOrganization(organizationName);
	    	
	    	 return RespDTO.onSuc(organization);
	    }
	    
	    @ApiOperation(value = "添加构信息", notes = "机构信息")
	    @PostMapping("/addOrganization")
	    @SysLogger("addOrganization")
	    public RespDTO<OrganizationVO> addOrganization(OrganizationVO  organizationVO){
	    	//TODO
	    	ResultModelDTO resultMode = new ResultModelDTO();
	    	String organizationName = organizationVO.getOrganizationName();
	    	List<Organization> organizationList = organizationFacade.findOrganization(organizationName);
	    	if(organizationList.size()>0){
	    		resultMode.setMessage("该机构存在");
	    		return RespDTO.onSuc(resultMode);
	    	}
	    	Organization organization = new Organization();
	    	organization.setName(organizationVO.getOrganizationName());
	    	organization.setType(organizationVO.getType());
	    	organization.setPrincipal(organizationVO.getPrincipal());
	    	organization.setSubNum(organizationVO.getSubNum());
	    	organization.setAddress(organizationVO.getAddress());
	    	organization.setGmtCreate(DateUtil.now());
	    	//TODO organization.setModifier(UserUtils.getCurrentPrincipleID());
	    	organization.setCreator("5");
	    	
	    	boolean op = organizationFacade.save(organization);
	    	
	    	resultMode.setMessage(op+"");
	    	 return RespDTO.onSuc(resultMode);
	    }
	    
	    @ApiOperation(value = "添加用户信息和机构信息管理员", notes = "用户信息和机构信息的绑定")
	    @PostMapping("/addUserInfo")
	    @SysLogger("addUserInfo")
	    public RespDTO<UserAndOrganizationVO> addUserInfo(UserAndOrganizationVO  userAndOrganizationVO){
	    	//TODO 先查找机构，获取机构id,再注册用户,返回用户id, 取到用户id和 机构id ,查询用户机构关联表，在进行绑定
	    	//User user = new User();
	    	ResultModelDTO resultMode = new ResultModelDTO();
	    	String username = userAndOrganizationVO.getUserName();
	    	 User user=  userFacade.getUserInfo(username);
	    	 System.out.println(user);
	    	 if(user!=null){
	    		 resultMode.setMessage("该用户存在");
		         return RespDTO.onSuc(resultMode); 
	    	 }
	    	 
	    	 
	    	 
	    	 resultMode.setMessage("用户不存在"); 
	    	 return RespDTO.onSuc(resultMode);
	    } 
	    
	    
}
